@@ -7,24 +7,24 @@
 /// Represents C++'s `operator<`.
 pub trait Lt<Rhs: ?Sized = Self> {
     /// This method tests less than (for `self` and `other`) and is used by the `<` operator.
-    fn lt(&self, other: &Rhs) -> bool;
+    unsafe fn lt(&self, other: &Rhs) -> bool;
 }
 
 /// Represents C++'s `operator<=`.
 pub trait Le<Rhs: ?Sized = Self> {
     /// This method tests less than or equal to (for `self` and `other`) and is used by the `<=`
-    fn le(&self, other: &Rhs) -> bool;
+    unsafe fn le(&self, other: &Rhs) -> bool;
 }
 
 /// Represents C++'s `operator>`.
 pub trait Gt<Rhs: ?Sized = Self> {
     /// This method tests greater than (for `self` and `other`) and is used by the `>` operator.
-    fn gt(&self, other: &Rhs) -> bool;
+    unsafe fn gt(&self, other: &Rhs) -> bool;
 }
 
 /// Represents C++'s `operator>=`.
 pub trait Ge<Rhs: ?Sized = Self> {
     /// This method tests greater than or equal to (for `self` and `other`) and is used by the `>=`
     /// operator.
-    fn ge(&self, other: &Rhs) -> bool;
+    unsafe fn ge(&self, other: &Rhs) -> bool;
 }
